@@ -1,3 +1,3 @@
 # Don't define aliases in plain Bourne shell
 [ -n "${BASH_VERSION}${KSH_VERSION}${ZSH_VERSION}" ] || return 0
-alias mc='. /2022Q2/libexec/mc/mc-wrapper.sh'
+alias mc='. /usr/local/libexec/mc/mc-wrapper.sh'
